@@ -45,7 +45,7 @@ class RKClient:
     """
 
     def __init__(self, receiver_url: str,
-                 emitter_id: Optional[UUID] = None,
+                 emitter_id: str,
                  timeout_sec: int = 5,
                  insecure: bool = True,
                  user_auth: str = '',
@@ -62,8 +62,6 @@ class RKClient:
         self.receiver_request = RequestHelper(receiver_url, timeout_sec, insecure, user_auth, puc_auth)
         log.info(f"ver {RK_VERSION}, connecting to: {receiver_url}")
 
-        if emitter_id is None:
-            emitter_id = uuid1()
         self.emitter_id = emitter_id
 
         if user_auth:
@@ -89,7 +87,7 @@ class RKClient:
                     predecessor_id: Optional[UUID] = None,
                     properties: Optional[Dict] = None,
                     tag_name: str = 'latest',
-                    tag_namespace: Optional[UUID] = None) -> PEM:
+                    tag_namespace: Optional[str] = None) -> PEM:
         """
         In memory creation of PEM
         :param pem_type: user defined type of event
@@ -106,26 +104,21 @@ class RKClient:
             pem.Properties = properties
         pem.Tag = tag_name
         if tag_namespace is None:
-            pem.TagNamespace = self.emitter_id.hex
+            pem.TagNamespace = self.emitter_id
         else:
-            pem.TagNamespace = tag_namespace.hex
+            pem.TagNamespace = tag_namespace
         return pem
 
     def prepare_artifact(self,
-                         artifact_type: str,
-                         properties: Dict[str, str],
-                         uid: Optional[UUID] = None) -> Artifact:
+                         name: str,
+                         properties: Dict[str, str]) -> Artifact:
         """
         In memory creation of Artifact. It needs to be passed to PEM.add_uses/produces_artifact()
-        :param artifact_type:
+        :param name:
         :param properties:
-        :param uid:
         :return: new Artifact
         """
-        if uid is None:
-            uid = uuid1()
-        art = Artifact(uid, artifact_type, properties)
-        return art
+        return Artifact(name, properties)
 
     def send_pem(self, pem: PEM) -> Tuple[str, bool]:
         """
@@ -149,18 +142,19 @@ class RKClient:
 
         return _handle_request(_get_info, "Getting info", True)
 
-    def get_tag(self, namespace: UUID, tag_name: str) -> Tuple[str, bool]:
+    def get_tag(self, namespace: str, tag_name: str) -> Tuple[str, bool]:
         """
         Returned tag is UUID in hex (do: UUID(hex=result))
         :return: check class description
         """
         def _get_tag():
             tag_base64 = _encode_as_base64(tag_name)
-            return self.receiver_request.get(f"/tag/{namespace.hex}/{tag_base64}")
+            namespace_base64 = _encode_as_base64(namespace)
+            return self.receiver_request.get(f"/tag/{namespace_base64}/{tag_base64}")
 
         return _handle_request(_get_tag, "Getting tag", True)
 
-    def set_tag(self, namespace: UUID, tag_name: str, pem: PEM) -> Tuple[str, bool]:
+    def set_tag(self, namespace: str, tag_name: str, pem: PEM) -> Tuple[str, bool]:
         """
         Sets tag_name on pem.ID, within namespace
         :param tag_name: can contain space, / and other characters, but recommended charset: is A-Za-z0-9_-
@@ -170,7 +164,8 @@ class RKClient:
         """
         def _set_tag():
             tag_base64 = _encode_as_base64(tag_name)
-            return self.receiver_request.post(f"/tag/{namespace.hex}/{tag_base64}/{pem.ID.hex}", tag_base64)
+            namespace_base64 = _encode_as_base64(namespace)
+            return self.receiver_request.post(f"/tag/{namespace_base64}/{tag_base64}/{pem.ID.hex}", tag_base64)
 
         return _handle_request(_set_tag, "Setting tag")
 
