@@ -17,30 +17,28 @@ class ArtifactSerialization:
         return ArtifactSerialization.from_dict(obj)
 
     @staticmethod
-    def to_dict(art: Artifact) -> Dict:
+    def to_dict(artifact: Artifact) -> Dict:
         obj = {
-            "ID": art.ID.hex,
-            "Type": art.Type,
-            "Properties": art.Properties,
-            "CreatedAt": art.CreatedAt,
+            "Name": artifact.Name,
+            "Properties": artifact.Properties,
+            "CreatedAt": artifact.CreatedAt,
             "TaxonomyFiles": None,
         }
-        if art.TaxonomyFiles is not None:
-            obj["TaxonomyFiles"] = {tkey: _encode_as_base64(tval) for tkey, tval in art.TaxonomyFiles.items()}
+        if artifact.TaxonomyFiles is not None:
+            obj["TaxonomyFiles"] = {tkey: _encode_as_base64(tval) for tkey, tval in artifact.TaxonomyFiles.items()}
         return obj
 
     @staticmethod
     def from_dict(d: Dict) -> Artifact:
-        art = Artifact(
-            id=UUID(hex=d['ID']),
-            artifact_type=d['Type'],
+        artifact = Artifact(
+            name=d['Name'],
             properties=d['Properties'],
         )
-        art.CreatedAt = d['CreatedAt']
-        art.TaxonomyFiles = None
+        artifact.CreatedAt = d['CreatedAt']
+        artifact.TaxonomyFiles = None
         if d['TaxonomyFiles'] is not None:
-            art.TaxonomyFiles = {tkey: _decode_from_base64(tval) for tkey, tval in d['TaxonomyFiles'].items()}
-        return art
+            artifact.TaxonomyFiles = {tkey: _decode_from_base64(tval) for tkey, tval in d['TaxonomyFiles'].items()}
+        return artifact
 
 
 class PEMSerialization:
@@ -54,7 +52,7 @@ class PEMSerialization:
             "ID": pem.ID.hex,
             "Type": pem.Type,
             "Predecessor": pred_id,
-            "Emitter": pem.Emitter.hex,
+            "Emitter": pem.Emitter,
             "TimestampClient": pem.TimestampClient,
             "TimestampReceived": pem.TimestampReceived,
             "Properties": pem.Properties,
@@ -80,15 +78,15 @@ class PEMSerialization:
         pem = PEM(UUID(hex=obj["ID"]),
                   obj["Type"],
                   pred,
-                  UUID(hex=obj["Emitter"]),
+                  obj["Emitter"],
                   obj["TimestampClient"])
         pem.Properties = obj["Properties"]
         pem.Tag = obj["Tag"]
         pem.TagNamespace = obj["TagNamespace"]
 
         if art_solely_id:
-            pem.UsesArtifacts = [Artifact(UUID(hex=uid), '', {}, True) for uid in obj["UsesArtifacts"]]
-            pem.ProducesArtifacts = [Artifact(UUID(hex=uid), '', {}, True) for uid in obj["ProducesArtifacts"]]
+            pem.UsesArtifacts = [Artifact(name, {}, True) for name in obj["UsesArtifacts"]]
+            pem.ProducesArtifacts = [Artifact(name, {}, True) for name in obj["ProducesArtifacts"]]
         else:
             pem.UsesArtifacts = [ArtifactSerialization.from_dict(a) for a in obj["UsesArtifacts"]]
             pem.ProducesArtifacts = [ArtifactSerialization.from_dict(a) for a in obj["ProducesArtifacts"]]
@@ -112,6 +110,7 @@ def _decode_from_base64(content_base64: str) -> str:
 @dataclass
 class Info:
     version: str
+    pem_version: str
     pem_size_limit: int
     auth_required: bool
     pem_auth_required: bool
